@@ -9,25 +9,17 @@
   target_os = "openbsd"
 ))]
 
-use crate::window::Window;
-
 pub use crate::platform_impl::hit_test;
+use crate::window::Window;
 
 /// Additional methods on `Window` that are specific to Unix.
 pub trait WindowExtUnix {
   /// Returns the `ApplicatonWindow` from gtk crate that is used by this window.
   fn gtk_window(&self) -> &gtk::ApplicationWindow;
-
-  /// Not to display window icon in the task bar.
-  fn skip_taskbar(&self);
 }
 
 impl WindowExtUnix for Window {
   fn gtk_window(&self) -> &gtk::ApplicationWindow {
     &self.window.window
   }
-
-  fn skip_taskbar(&self) {
-    self.window.skip_taskbar()
-  }
 }
