@@ -14,7 +14,6 @@ use crate::{
   error::{ExternalError, NotSupportedError, OsError as RootOsError},
   event::{Event, WindowEvent},
   icon::Icon,
-  menu::Menu,
   monitor::MonitorHandle as RootMonitorHandle,
   platform::ios::{MonitorHandleExtIOS, ScreenEdge, ValidOrientations},
   platform_impl::platform::{
@@ -24,7 +23,7 @@ use crate::{
       id, CGFloat, CGPoint, CGRect, CGSize, UIEdgeInsets, UIInterfaceOrientationMask, UIRectEdge,
       UIScreenOverscanCompensation,
     },
-    monitor, view, EventLoopWindowTarget, MonitorHandle,
+    monitor, view, EventLoopWindowTarget, Menu, MonitorHandle,
   },
   window::{CursorIcon, Fullscreen, UserAttentionType, WindowAttributes, WindowId as RootWindowId},
 };
@@ -51,7 +50,7 @@ impl Inner {
     debug!("`Window::set_title` is ignored on iOS")
   }
 
-  pub fn set_menu(&self, _menu: Option<Vec<Menu>>) {
+  pub fn set_menu(&self, _menu: Option<Menu>) {
     debug!("`Window::set_menu` is ignored on iOS")
   }
 
@@ -210,6 +209,11 @@ impl Inner {
     false
   }
 
+  pub fn is_visible(&self) -> bool {
+    log::warn!("`Window::is_visible` is ignored on iOS");
+    false
+  }
+
   pub fn is_resizable(&self) -> bool {
     warn!("`Window::is_resizable` is ignored on iOS");
     false
@@ -292,10 +296,22 @@ impl Inner {
     warn!("`Window::set_ime_position` is ignored on iOS")
   }
 
+  pub fn set_skip_taskbar(&self, _skip: bool) {
+    warn!("`Window::set_skip_taskbar` is ignored on iOS")
+  }
+
   pub fn request_user_attention(&self, _request_type: Option<UserAttentionType>) {
     warn!("`Window::request_user_attention` is ignored on iOS")
   }
 
+  pub fn hide_menu(&self) {
+    warn!("`Window::hide_menu` is ignored on iOS")
+  }
+
+  pub fn show_menu(&self) {
+    warn!("`Window::show_menu` is ignored on iOS")
+  }
+
   // Allow directly accessing the current monitor internally without unwrapping.
   fn current_monitor_inner(&self) -> RootMonitorHandle {
     unsafe {
