@@ -18,7 +18,6 @@ use crate::{
   },
   error::{ExternalError, NotSupportedError, OsError as RootOsError},
   icon::Icon,
-  menu::Menu,
   monitor::{MonitorHandle as RootMonitorHandle, VideoMode as RootVideoMode},
   platform::macos::WindowExtMacOS,
   platform_impl::platform::{
@@ -46,6 +45,8 @@ use objc::{
   runtime::{Class, Object, Sel, BOOL, NO, YES},
 };
 
+use super::Menu;
+
 #[derive(Debug, Copy, Clone, PartialEq, Eq, PartialOrd, Ord, Hash)]
 pub struct Id(pub usize);
 
@@ -455,7 +456,7 @@ impl UnownedWindow {
     }
   }
 
-  pub fn set_menu(&self, menu: Option<Vec<Menu>>) {
+  pub fn set_menu(&self, menu: Option<Menu>) {
     unsafe {
       util::set_menu_async(*self.ns_window, menu);
     }
@@ -472,7 +473,12 @@ impl UnownedWindow {
   // Shortener for set_visible(true)
   pub fn set_focus(&self) {
     unsafe {
-      util::set_focus(*self.ns_window);
+      let is_minimized: BOOL = msg_send![*self.ns_window, isMiniaturized];
+      let is_visible: BOOL = msg_send![*self.ns_window, isVisible];
+
+      if is_minimized == NO && is_visible == YES {
+        util::set_focus(*self.ns_window);
+      }
     }
   }
 
@@ -744,12 +750,19 @@ impl UnownedWindow {
     self.is_zoomed()
   }
 
+  #[inline]
+  pub fn is_visible(&self) -> bool {
+    let is_visible: BOOL = unsafe { msg_send![*self.ns_window, isVisible] };
+    is_visible == YES
+  }
+
   #[inline]
   pub fn is_resizable(&self) -> bool {
     let is_resizable: BOOL = unsafe { msg_send![*self.ns_window, isResizable] };
     is_resizable == YES
   }
 
+  #[inline]
   pub fn is_decorated(&self) -> bool {
     let current_mask = unsafe { self.ns_window.styleMask() };
     if current_mask
@@ -1019,6 +1032,15 @@ impl UnownedWindow {
     }
   }
 
+  #[inline]
+  pub fn hide_menu(&self) {}
+
+  #[inline]
+  pub fn show_menu(&self) {}
+
+  #[inline]
+  pub fn set_skip_taskbar(&self, _skip: bool) {}
+
   #[inline]
   // Allow directly accessing the current monitor internally without unwrapping.
   pub(crate) fn current_monitor_inner(&self) -> RootMonitorHandle {
