@@ -40,22 +40,33 @@ lazy_static! {
 }
 
 pub struct MenuHandler {
+  window_id: Option<RootWindowId>,
   menu_type: MenuType,
   send_event: Box<dyn Fn(Event<'static, ()>)>,
 }
 
 impl MenuHandler {
-  pub fn new(send_event: Box<dyn Fn(Event<'static, ()>)>, menu_type: MenuType) -> MenuHandler {
+  pub fn new(
+    send_event: Box<dyn Fn(Event<'static, ()>)>,
+    menu_type: MenuType,
+    window_id: Option<RootWindowId>,
+  ) -> MenuHandler {
     MenuHandler {
+      window_id,
       send_event,
       menu_type,
     }
   }
   pub fn send_click_event(&self, menu_id: u16) {
-    (self.send_event)(Event::MenuEvent {
-      menu_id: MenuId(menu_id),
-      origin: self.menu_type,
-    });
+    // we send only tray event as the window event
+    // is catched into the main event_loop process.
+    if self.menu_type == MenuType::ContextMenu {
+      (self.send_event)(Event::MenuEvent {
+        menu_id: MenuId(menu_id),
+        origin: self.menu_type,
+        window_id: self.window_id,
+      });
+    }
   }
 
   pub fn send_event(&self, event: Event<'static, ()>) {
