@@ -3,9 +3,9 @@
 
 use crate::{
   dpi::{PhysicalPosition, Size},
-  event::ModifiersState,
   icon::Icon,
-  platform_impl::platform::{event_loop, util},
+  keyboard::ModifiersState,
+  platform_impl::platform::{event_loop, keyboard::KeyEventBuilder, minimal_ime::MinimalIme, util},
   window::{CursorIcon, Fullscreen, Theme, WindowAttributes},
 };
 use parking_lot::MutexGuard;
@@ -37,6 +37,10 @@ pub struct WindowState {
   pub current_theme: Theme,
   pub preferred_theme: Option<Theme>,
   pub high_surrogate: Option<u16>,
+
+  pub key_event_builder: KeyEventBuilder,
+  pub ime_handler: MinimalIme,
+
   pub window_flags: WindowFlags,
 }
 
@@ -125,6 +129,8 @@ impl WindowState {
       current_theme,
       preferred_theme,
       high_surrogate: None,
+      key_event_builder: KeyEventBuilder::default(),
+      ime_handler: MinimalIme::default(),
       window_flags: WindowFlags::empty(),
     }
   }
